package com.sun.corba.se.impl.legacy.connection;

import com.sun.corba.se.impl.orbutil.ORBUtility;
import java.util.Collection;
import java.util.Iterator;
import org.omg.CORBA.INTERNAL;
import com.sun.corba.se.spi.legacy.connection.LegacyServerSocketEndPointInfo;
import org.omg.CORBA.CompletionStatus;
import com.sun.corba.se.impl.logging.ORBUtilSystemException;
import com.sun.corba.se.spi.orb.ORB;
import com.sun.corba.se.spi.legacy.connection.LegacyServerSocketManager;

public class LegacyServerSocketManagerImpl implements LegacyServerSocketManager
{
    protected ORB orb;
    private ORBUtilSystemException wrapper;
    
    public LegacyServerSocketManagerImpl(ORB orb) {
        this.orb = orb;
        this.wrapper = ORBUtilSystemException.get(orb, "rpc.transport");
    }
    
    public int legacyGetTransientServerPort(String s) {
        return this.legacyGetServerPort(s, false);
    }
    
    public synchronized int legacyGetPersistentServerPort(String s) {
        if (this.orb.getORBData().getServerIsORBActivated()) {
            return this.legacyGetServerPort(s, true);
        }
        if (this.orb.getORBData().getPersistentPortInitialized()) {
            return this.orb.getORBData().getPersistentServerPort();
        }
        throw this.wrapper.persistentServerportNotSet(CompletionStatus.COMPLETED_MAYBE);
    }
    
    public synchronized int legacyGetTransientOrPersistentServerPort(String s) {
        return this.legacyGetServerPort(s, this.orb.getORBData().getServerIsORBActivated());
    }
    
    public synchronized LegacyServerSocketEndPointInfo legacyGetEndpoint(String str) {
        Iterator<Object> acceptorIterator = this.getAcceptorIterator();
        while (acceptorIterator.hasNext()) {
            LegacyServerSocketEndPointInfo cast = this.cast(acceptorIterator.next());
            if (cast != null && str.equals(cast.getName())) {
                return cast;
            }
            continue;
        }
        throw new INTERNAL("No acceptor for: " + str);
    }
    
    public boolean legacyIsLocalServerPort(int n) {
        Iterator<Object> acceptorIterator = this.getAcceptorIterator();
        while (acceptorIterator.hasNext()) {
            LegacyServerSocketEndPointInfo cast = this.cast(acceptorIterator.next());
            if (cast != null && cast.getPort() == n) {
                return true;
            }
            continue;
        }
        return false;
    }
    
    private int legacyGetServerPort(String anObject, boolean b) {
        Iterator<Object> acceptorIterator = this.getAcceptorIterator();
        while (acceptorIterator.hasNext()) {
            LegacyServerSocketEndPointInfo cast = this.cast(acceptorIterator.next());
            if (cast != null && cast.getType().equals(anObject)) {
                if (b) {
                    return cast.getLocatorPort();
                }
                return cast.getPort();
            }
            else {
                continue;
            }
        }
        return -1;
    }
    
    private Iterator getAcceptorIterator() {
        Collection<Object> acceptors = this.orb.getCorbaTransportManager().getAcceptors(null, null);
        if (acceptors != null) {
            return acceptors.iterator();
        }
        throw this.wrapper.getServerPortCalledBeforeEndpointsInitialized();
    }
    
    private LegacyServerSocketEndPointInfo cast(Object o) {
        if ((o instanceof LegacyServerSocketEndPointInfo)) {
            return (LegacyServerSocketEndPointInfo)o;
        }
        return null;
    }
    
    protected void dprint(String s) {
        ORBUtility.dprint("LegacyServerSocketManagerImpl", s);
    }
}
